@@ -1,31 +1,29 @@
 import { css, cx } from '@emotion/css';
 import { capitalize } from 'lodash';
-import React, { useState } from 'react';
+import React from 'react';
 import { useForm } from 'react-hook-form';
 import { connect, ConnectedProps } from 'react-redux';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { locationService, reportInteraction } from '@grafana/runtime';
-import { Button, ConfirmModal, FieldSet, Icon, LinkButton, useStyles2 } from '@grafana/ui';
+import { FieldSet, Icon, LinkButton, useStyles2 } from '@grafana/ui';
 import { formatUtcOffset } from '@grafana/ui/src/components/DateTimePickers/TimeZonePicker/TimeZoneOffset';
-import { contextSrv } from 'app/core/services/context_srv';
 
 import {
-  AccessControlAction,
   EnterpriseStoreState,
   ReportDashboard,
   ReportDataToRender,
   ReportState,
+  SchedulingData,
   SchedulingFrequency,
   StepKey,
 } from '../../types';
 import { BASE_URL, defaultScaleFactor, reportScales } from '../constants';
-import { createReport, deleteReport, loadReport, updateReport } from '../state/actions';
+import { createReport, updateReport } from '../state/actions';
 import { clearReportState, initialState } from '../state/reducers';
 import { getFormatted, getTimeRangeDisplay } from '../utils/dateTime';
 import { getFormatsDisplay } from '../utils/formats';
-import { getReportStateInfo } from '../utils/reportState';
-import { showWorkdaysOnly } from '../utils/scheduler';
+import { schedulePreview, showWorkdaysOnly } from '../utils/scheduler';
 import { getSectionUrl } from '../utils/url';
 import { getMissingFields } from '../utils/validation';
 
@@ -42,8 +40,6 @@ const mapStateToProps = (state: EnterpriseStoreState) => {
 
 const mapActionsToProps = {
   createReport,
-  loadReport,
-  deleteReport,
   updateReport,
   clearReportState,
 };
@@ -51,58 +47,20 @@ const mapActionsToProps = {
 const connector = connect(mapStateToProps, mapActionsToProps);
 export type Props = ConnectedProps<typeof connector> & { reportId?: string };
 
-export const Confirm = ({
-  report,
-  createReport,
-  loadReport,
-  updateReport,
-  deleteReport,
-  clearReportState,
-  isUpdated,
-  reportId,
-}: Props) => {
+export const Confirm = ({ report, createReport, updateReport, clearReportState, isUpdated, reportId }: Props) => {
   const { formats, options, schedule, dashboards } = report;
   const {
     handleSubmit,
     formState: { isSubmitSuccessful },
   } = useForm();
-  const [isModalOpen, setIsModalOpen] = useState(false);
+
   const styles = useStyles2(getStyles);
   const editMode = !!reportId && !isUpdated;
   const disableSubmit = getMissingFields(report);
-  const canDeleteReport = contextSrv.hasPermission(AccessControlAction.ReportingDelete);
-  const canEditReport = contextSrv.hasPermission(AccessControlAction.ReportingWrite);
-  const { showPlay, disableEdit, reportState } = getReportStateInfo(report);
+
   const { time: startTime, date: startDate } = getFormatted(schedule.startDate);
   const { time: endTime, date: endDate } = getFormatted(schedule.endDate);
 
-  const onToggleReportState = async () => {
-    let newState = ReportState.Scheduled;
-
-    if ([ReportState.Draft, ReportState.Expired].includes(reportState)) {
-      newState = reportState;
-    } else if (reportState !== ReportState.Paused) {
-      newState = ReportState.Paused;
-    }
-
-    // api call to update report data
-    await updateReport({
-      ...report,
-      state: newState,
-    });
-
-    // Update report data on state
-    if (reportId) {
-      loadReport(parseInt(reportId, 10));
-    }
-  };
-
-  const onDeleteReport = () => {
-    deleteReport(report.id);
-    setIsModalOpen(false);
-    locationService.push(BASE_URL);
-  };
-
   const submitReport = async () => {
     const createOrUpdate = !!report.id ? updateReport : createReport;
     if (report.state === ReportState.Draft) {
@@ -149,7 +107,7 @@ export const Confirm = ({
           },
           { title: 'Time range', value: getTimeRangeDisplay(field.timeRange) },
           // Add empty row for spacing in case of multiple dashboards
-          ...(arr.length > 1 ? [{ title: '', value: '' }] : []),
+          ...(arr.length > 1 && index !== arr.length - 1 ? [{ title: '', value: '' }] : []),
         ];
       }),
     },
@@ -188,8 +146,18 @@ export const Confirm = ({
             ]
           : []),
         ...(showWorkdaysOnly(schedule.frequency, schedule.intervalFrequency)
-          ? [{ title: 'Send Monday to Friday only', value: schedule.workdaysOnly ? 'Yes' : 'No' }]
+          ? [
+              {
+                title: 'Send Monday to Friday only',
+                value: schedule.workdaysOnly ? (
+                  <Icon name={'check'} size={'xl'} />
+                ) : (
+                  <Icon name={'minus'} size={'xl'} />
+                ),
+              },
+            ]
           : []),
+        { value: schedulePreview(report.schedule as SchedulingData), title: '' },
       ],
     },
     {
@@ -201,7 +169,10 @@ export const Confirm = ({
         { title: 'Recipients*', value: report.recipients, id: 'recipients', required: true },
         { title: 'Reply-to-email', value: report.replyTo || 'none' },
         { title: 'Message', value: report.message || 'none' },
-        { title: 'Dashboard link', value: report.enableDashboardUrl ? 'Included' : 'Not included' },
+        {
+          title: 'Dashboard link',
+          value: report.enableDashboardUrl ? <Icon name={'check'} size={'xl'} /> : <Icon name={'minus'} size={'xl'} />,
+        },
       ],
     },
   ];
@@ -215,59 +186,20 @@ export const Confirm = ({
       onSubmit={handleSubmit(submitReport)}
       reportId={reportId}
     >
-      {editMode && (
-        <div className={styles.editActions}>
-          <Button
-            type={'button'}
-            variant={'secondary'}
-            icon={showPlay ? 'play' : 'pause'}
-            disabled={disableEdit || !canEditReport}
-            onClick={onToggleReportState}
-          >
-            {showPlay ? 'Resume' : 'Pause'}
-          </Button>
-          <LinkButton
-            href={getSectionUrl(StepKey.SelectDashboard, reportId)}
-            type={'button'}
-            variant={'secondary'}
-            icon={'pen'}
-            disabled={!canEditReport}
-          >
-            Edit report
-          </LinkButton>
-          <Button
-            type={'button'}
-            variant={'secondary'}
-            icon={'trash-alt'}
-            disabled={!canDeleteReport}
-            onClick={() => setIsModalOpen(true)}
-          >
-            Delete report
-          </Button>
-          <ConfirmModal
-            isOpen={isModalOpen}
-            title={'Delete report'}
-            body={'Are you sure you want to delete this report?'}
-            confirmText={'Delete'}
-            onConfirm={onDeleteReport}
-            onDismiss={() => setIsModalOpen(false)}
-          />
-        </div>
-      )}
       <FieldSet label={editMode ? '' : '5. Confirm'}>
         {reportData.map((section) => {
           const hasMissingFields = getMissingFields(report, section.id);
           return (
-            <div className={cx(styles.section, hasMissingFields && styles.warningSection)} key={section.title}>
+            <div className={styles.section} key={section.title}>
               <div className={styles.sectionHeader}>
-                <h3 className={styles.sectionTitle}>{section.title}</h3>
+                <h5 className={styles.sectionTitle}>{section.title}</h5>
                 <LinkButton
-                  variant={'secondary'}
-                  fill={hasMissingFields ? 'solid' : 'outline'}
+                  variant={hasMissingFields ? 'primary' : 'secondary'}
+                  fill={'text'}
                   href={getSectionUrl(section.id, reportId)}
                   size={'sm'}
                 >
-                  Edit section
+                  Edit
                 </LinkButton>
               </div>
               {section.items
@@ -284,7 +216,9 @@ export const Confirm = ({
                       </div>
                     </div>
                   ) : (
-                    <div className={styles.row} key={index} />
+                    <div className={cx(styles.row, styles.textMuted)} key={index}>
+                      {row.value}
+                    </div>
                   );
                 })}
             </div>
@@ -301,23 +235,25 @@ const getStyles = (theme: GrafanaTheme2) => {
   return {
     section: css`
       width: 100%;
-      padding: ${theme.spacing(3)};
-      background-color: ${theme.colors.background.secondary};
+      padding: ${theme.spacing(3, 0)};
       margin-bottom: ${theme.spacing(3)};
     `,
     sectionHeader: css`
       display: flex;
       align-items: center;
       justify-content: space-between;
-      margin-bottom: ${theme.spacing(3)};
+      padding: ${theme.spacing(1)};
+      border: 1px solid ${theme.colors.border.weak};
     `,
-    warningSection: css`
-      border: 1px solid ${theme.colors.warning.text};
+    sectionTitle: css`
+      margin: 0;
     `,
     row: css`
+      border: 1px solid ${theme.colors.border.weak};
+      border-top: none;
       display: flex;
       width: 100%;
-      padding: ${theme.spacing(1, 0)};
+      padding: ${theme.spacing(1)};
     `,
     warning: css`
       color: ${theme.colors.warning.text};
@@ -333,26 +269,11 @@ const getStyles = (theme: GrafanaTheme2) => {
       width: 70%;
       word-break: break-word;
     `,
-    sectionTitle: css`
-      margin: 0;
-    `,
     dashboardLink: css`
       color: ${theme.colors.text.primary};
       font-size: ${theme.typography.body.fontSize};
       margin-top: 0;
     `,
-    editActions: css`
-      display: flex;
-      align-items: center;
-      justify-content: flex-end;
-      width: 100%;
-      margin-bottom: ${theme.spacing(3)};
-
-      button,
-      a {
-        margin-left: ${theme.spacing(2)};
-      }
-    `,
   };
 };
 
